@@ -749,6 +749,9 @@ proc rivet_cgi_server {addr port foreground initscp logfile errorlogfile} {
 	catch {
 		set canfork [infox have_waitpid]
 	}
+	if {$::tcl_platform(platform) == "windows"} {
+		set canfork 0
+	}
 
 	if {$initscp != ""} {
 		uplevel #0 $initscp
@@ -1075,7 +1078,7 @@ if {![info exists ::env(GATEWAY_INTERFACE)]} {
 			exit 0
 		}
 		"--version" {
-			tcl_puts "RivetStarkit version 0.5.0.1377"
+			tcl_puts "RivetStarkit version 0.5.0.1415"
 			exit 0
 		}
 		default {
